@@ -4,16 +4,18 @@ use git_filter_server::{GitFilterServer, ProcessingType, Processor};
 use std::{
     collections::{HashMap, HashSet},
     fs::OpenOptions,
-    io::{BufRead, BufReader, Write},
+    io::{BufRead, BufReader, Write, Cursor},
     path::PathBuf,
     process::Command,
     rc::Rc,
     sync::Arc,
 };
 use structopt::StructOpt;
+use structopt::clap::AppSettings::*;
 
 #[derive(StructOpt)]
 #[structopt(name = "cfgcomment", author)]
+#[structopt(setting(ColorAuto), setting(ColoredHelp))]
 enum Opts {
     /// Configure git filter for resetting comments on stage
     Init,
@@ -41,14 +43,18 @@ impl Processor for UncommentingProcessor {
         &mut self,
         pathname: &str,
         _process_type: ProcessingType,
-        input: &mut R,
+        read: &mut R,
         output: &mut W,
     ) -> anyhow::Result<()> {
+        let mut input = Vec::new();
+        read.read_to_end(&mut input)?;
+        let mut input = Cursor::new(input);
+
         let path = PathBuf::from(pathname);
         let extension = match path.as_path().extension() {
             Some(v) => v,
             None => {
-                std::io::copy(input, output)?;
+                std::io::copy(&mut input, output)?;
                 return Ok(());
             }
         };
@@ -56,7 +62,7 @@ impl Processor for UncommentingProcessor {
         let desc = match self.lang_config.get(&extension) {
             Some(v) => v,
             None => {
-                std::io::copy(input, output)?;
+                std::io::copy(&mut input, output)?;
                 return Ok(());
             }
         };
